@@ -61,6 +61,7 @@ pub(crate) struct DirInfo {
     /// size of a directory
     pub(crate) dir_size: u64,
     /// number of files of a directory
+    #[allow(unused)] // used in tests iirc
     pub(crate) file_number: u64,
 }
 /// `CargoCachePaths` contains paths to all the subcomponents of the cargo cache
@@ -215,11 +216,9 @@ impl fmt::Display for Error {
                 "Failed to Cargo.toml manifest in {} or downwards.",
                 dir.display()
             ),
-            Self::QueryRegexFailedParsing(regex) => write!(
-                f,
-                "Failed to parse regular expression \"{}\"",
-                regex.to_string()
-            ),
+            Self::QueryRegexFailedParsing(regex) => {
+                write!(f, "Failed to parse regular expression \"{}\"", regex)
+            }
             Self::GitGCFile(path) => write!(
                 f,
                 "Tried to \"git gc\" a file instead of a directory: \"{}\"",
@@ -691,12 +690,12 @@ pub(crate) fn size_diff_format(
 pub(crate) fn print_size_changed_summary(
     previous_total_size: u64,
     cargo_cache: &CargoCachePaths,
-    mut bin_cache: &mut bin::BinaryCache,
-    mut checkouts_cache: &mut git_checkouts::GitCheckoutCache,
-    mut bare_repos_cache: &mut git_bare_repos::GitRepoCache,
-    mut registry_pkgs_cache: &mut registry_pkg_cache::RegistryPkgCaches,
-    mut registry_index_caches: &mut registry_index::RegistryIndicesCache,
-    mut registry_sources_caches: &mut registry_sources::RegistrySourceCaches,
+    bin_cache: &mut bin::BinaryCache,
+    checkouts_cache: &mut git_checkouts::GitCheckoutCache,
+    bare_repos_cache: &mut git_bare_repos::GitRepoCache,
+    registry_pkgs_cache: &mut registry_pkg_cache::RegistryPkgCaches,
+    registry_index_caches: &mut registry_index::RegistryIndicesCache,
+    registry_sources_caches: &mut registry_sources::RegistrySourceCaches,
 ) {
     // and invalidate the cache
     bin_cache.invalidate();
@@ -708,12 +707,12 @@ pub(crate) fn print_size_changed_summary(
 
     // and requery it to let it do its thing
     let cache_size_new = DirSizes::new(
-        &mut bin_cache,
-        &mut checkouts_cache,
-        &mut bare_repos_cache,
-        &mut registry_pkgs_cache,
-        &mut registry_index_caches,
-        &mut registry_sources_caches,
+        bin_cache,
+        checkouts_cache,
+        bare_repos_cache,
+        registry_pkgs_cache,
+        registry_index_caches,
+        registry_sources_caches,
         cargo_cache,
     )
     .total_size();
@@ -887,7 +886,7 @@ mod libtests {
         let output = ccp.to_string();
         let mut iter = output.lines().skip(1); // ??
 
-        let cargo_home = iter.next().unwrap();
+        let cargo_home2 = iter.next().unwrap();
 
         assert!(
             Regex::new(if cfg!(windows) {
@@ -896,7 +895,7 @@ mod libtests {
                 r"cargo home:.*/cargo_home_cargo_cache_paths_print"
             })
             .unwrap()
-            .is_match(cargo_home),
+            .is_match(cargo_home2),
             "cargo home: \"{:?}\"",
             cargo_home
         );
