@@ -30,7 +30,7 @@
     clippy::complexity,
     clippy::style,
     clippy::pedantic,
-    clippy::shadow_reuse,
+    //clippy::shadow_reuse,
     clippy::shadow_same,
     clippy::shadow_unrelated,
     clippy::string_add,
@@ -47,6 +47,7 @@
     clippy::let_unit_value,
     clippy::option_option,
     clippy::unnecessary_wraps,
+    clippy::unnested_or_patterns,
 //   clippy::wildcard_enum_match_arm // too many FPS for _ => unreachable!()
 )]
 // suppress these warnings:
@@ -55,7 +56,10 @@
 #![allow(clippy::wildcard_imports)] // breaks code, false positives
 #![allow(clippy::option_if_let_else)] // too pedantic, not that useful...
 #![allow(clippy::upper_case_acronyms)] // questionable
-#![allow(clippy::needless_for_each)] // I like my iterators :(
+#![allow(clippy::needless_for_each)]
+// I like my iterators :(
+// temporary disable because of false positive: https://github.com/rust-lang/rust-clippy/issues/7859
+#![allow(clippy::question_mark)]
 
 // for the "ci-autoclean" feature, we don't need all these modules so ignore them
 cfg_if::cfg_if! {
@@ -469,7 +473,7 @@ fn main() {
         _ => (),
     }
 
-    if size_changed && !config.is_present("dry-run") && !config.is_present("dry-run-deprecated") {
+    if size_changed && !config.is_present("dry-run") {
         // size has changed, print summary of how size has changed
 
         dirsizes::DirSizes::print_size_difference(
